@@ -1,6 +1,6 @@
 package POEx::IRC::Backend;
 {
-  $POEx::IRC::Backend::VERSION = '0.024001';
+  $POEx::IRC::Backend::VERSION = '0.024002';
 }
 
 use 5.10.1;
@@ -249,7 +249,7 @@ sub _register_controller {
 
 sub _accept_conn {
   ## Accepted connection to a listener.
-  my ($kernel, $self) = @_[KERNEL, OBJECT];
+  my (undef, $self) = @_[KERNEL, OBJECT];
   my ($sock, $p_addr, $p_port, $listener_id) = @_[ARG0 .. ARG3];
 
   ## Our peer's addr.
@@ -403,7 +403,7 @@ sub _create_listener {
   $self->listeners->{$id} = $listener;
 
   ## Real bound port/addr
-  my ($proto, $addr, $port) = get_unpacked_addr( $wheel->getsockname );
+  my (undef, undef, $port) = get_unpacked_addr( $wheel->getsockname );
   $listener->set_port($port) if $port;
 
   ## Tell our controller session
@@ -485,7 +485,7 @@ sub _create_connector {
   ##  bindaddr =>
   ##  ipv6 =>
   ##  ssl  =>
-  my ($kernel, $self) = @_[KERNEL, OBJECT];
+  my (undef, $self) = @_[KERNEL, OBJECT];
   my %args = @_[ARG0 .. $#_];
 
   $args{lc $_} = delete $args{$_} for keys %args;
@@ -634,7 +634,7 @@ sub _ircsock_input {
 
 sub _ircsock_error {
   ## Lost someone.
-  my ($kernel, $self) = @_[KERNEL, OBJECT];
+  my (undef, $self) = @_[KERNEL, OBJECT];
   my ($errstr, $w_id) = @_[ARG2, ARG3];
 
   my $this_conn = $self->wheels->{$w_id} || return;
@@ -647,7 +647,7 @@ sub _ircsock_error {
 
 sub _ircsock_flushed {
   ## Socket's been flushed; we may have something to do.
-  my ($kernel, $self, $w_id) = @_[KERNEL, OBJECT, ARG0];
+  my (undef, $self, $w_id) = @_[KERNEL, OBJECT, ARG0];
 
   my $this_conn = $self->wheels->{$w_id} || return;
 
@@ -820,10 +820,13 @@ q{
 
 =head1 NAME
 
-POEx::IRC::Backend - IRC client or server sockets
+POEx::IRC::Backend - IRC client or server backend
 
 =head1 SYNOPSIS
 
+  use POE;
+  use POEx::IRC::Backend;
+
   ## Spawn a Backend and register as the controlling session.
   my $backend = POEx::IRC::Backend->spawn(
     ## See POE::Component::SSLify (SSLify_Options):
